@@ -447,7 +447,7 @@ class Ui_MainWindow(object):
         self.label_sessiondur.setText(_translate("MainWindow", "Session duration (mins)"))
         self.plot.setText(_translate("MainWindow", "Plot"))
         self.tabs.setTabText(self.tabs.indexOf(self.dataexplorer), _translate("MainWindow", "Data Explorer"))
-        self.info_label.setText(_translate("MainWindow", "Current version v3.0.2 \n"
+        self.info_label.setText(_translate("MainWindow", "Current version v3.0.3 \n"
 "Created by Yifeng Cheng, Ph.D. \n"
 "Contact:\n"
 "(979)571-8531\n"
@@ -488,7 +488,7 @@ class MyApp (QtWidgets.QMainWindow, Ui_MainWindow):
     
     def __run_medpc2excel(self):
         datafolder = self.datafolder_path_input.toPlainText()
-        working_var_label = self.workingVar_label.toPlainText()
+        working_var_label = self.workingVar_label_text.toPlainText()
         #get path for all *. data file
         files = explore(datafolder,*[''],kernalmsg=False)
         #get a list of data file
